@@ -8,6 +8,20 @@ class TestCloudInit(unittest.TestCase):
         cmd = "sudo systemctl is-enabled cloud-init-local"
         utils_lib.run_cmd(self, cmd, cancel_ret='0', msg = "check cloud-init-local is enabled")
 
+    def test_check_cloudinit_cfg_no_wheel(self):
+        '''
+        bz: 1549638
+        cm: 01965459
+        polarion_id:
+        des: make sure there is no wheel in default_user's group in "/etc/cloud/cloud.cfg"
+        '''
+        cmd = 'sudo cat /etc/cloud/cloud.cfg'
+        utils_lib.run_cmd(self,
+                    cmd,
+                    expect_ret=0,
+                    expect_not_kw='wheel',
+                    msg='check /etc/cloud/cloud.cfg to make sure no wheel in default_user group(bz1549638)')
+
     def test_check_cloudinit_ds_identify_found(self):
         '''
         polarion_id:
@@ -23,6 +37,25 @@ class TestCloudInit(unittest.TestCase):
                     expect_kw='ds-identify _RET=found',
                     msg='check /run/cloud-init/cloud-init-generator.log')
 
+    def test_check_cloudinit_fingerprints(self):
+        '''
+        bz: 1957532
+        cm: 02905983
+        polarion_id:
+        check fingerprints is saved in /var/log/messages.
+        expected:
+            # grep -A 4 'BEGIN SSH HOST KEY FINGERPRINTS' /var/log/messages
+            May  6 02:57:58 ip-10-116-2-239 ec2[1441]: -----BEGIN SSH HOST KEY FINGERPRINTS-----
+            May  6 02:57:58 ip-10-116-2-239 ec2[1441]: 256 SHA256:n+iS6HUI/ApfkE/ZveBzBrIFSsmcL1YR/c3RsbPShd8 no comment (ECDSA)
+            May  6 02:57:58 ip-10-116-2-239 ec2[1441]: 256 SHA256:lZSyEuxf421H9y2DnoadjIvidZWXvGL3wfRlwAFBnms no comment (ED25519)
+            May  6 02:57:58 ip-10-116-2-239 ec2[1441]: 3072 SHA256:gysD1LLAkwZIovBEZdzX7s/dCJBegc+jnCtH7cJkIOo no comment (RSA)
+            May  6 02:57:58 ip-10-116-2-239 ec2[1441]: -----END SSH HOST KEY FINGERPRINTS-----
+        '''
+        cmd = "sudo grep -A 4 'BEGIN SSH HOST KEY FINGERPRINTS' /var/log/messages"
+        out = utils_lib.run_cmd(self, cmd, msg='get fingerprints in /var/log/messages')
+        if out.count('BEGIN') != out.count('SHA256')/3:
+            self.fail('fingerprints count {} does not match expected {}'.format(out.count('SHA256')/3,out.count('BEGIN')))
+
     def test_check_cloudinit_log_imdsv2(self):
         '''
         polarion_id:
