@@ -12,16 +12,17 @@ class TestLTP(unittest.TestCase):
         '''
         utils_lib.run_cmd(self, 'sudo rm -rf /opt/ltp/results/*')
         if file_name is not None and case_name is not None:
-            ltp_cmd = 'sudo /opt/ltp/runltp -f %s -s %s > ltplog 2>&1' % (
+            ltp_cmd = 'sudo /opt/ltp/runltp -f %s -s %s > /tmp/ltplog 2>&1' % (
                 file_name, case_name)
         elif file_name is None and case_name is not None:
-            ltp_cmd = 'sudo /opt/ltp/runltp -s %s > ltplog 2>&1' % case_name
+            ltp_cmd = 'sudo /opt/ltp/runltp -s %s > /tmp/ltplog 2>&1' % case_name
         elif file_name is not None and case_name is None:
-            ltp_cmd = 'sudo /opt/ltp/runltp -f %s > ltplog 2>&1' % file_name
+            ltp_cmd = 'sudo /opt/ltp/runltp -f %s > /tmp/ltplog 2>&1' % file_name
         self.log.info("LTP cmd: %s" % ltp_cmd)
         utils_lib.run_cmd(self, '\n')
         utils_lib.run_cmd(self, ltp_cmd, timeout=600)
         time.sleep(5)
+        utils_lib.run_cmd(self, 'sudo cat /tmp/ltplog')
         utils_lib.run_cmd(self,
                     'sudo cat /opt/ltp/results/*',
                     expect_kw='Total Failures: 0')
@@ -71,7 +72,7 @@ class TestLTP(unittest.TestCase):
     def test_ltp_cpuhotplug(self):
         '''
         polarion_id: RHEL7-98752
-        BZ#: 1464095
+        bz: 1464095
         '''
         # ltp will considering fail if more than 1 cpus cannot be offline
         # in bare metal instance
@@ -91,10 +92,10 @@ at least which ltp not handle')
     def test_ltp_hugemmap(self):
         '''
         polarion_id: RHEL7-88729
-        BZ#: 1312331
+        bz: 1312331
         '''
         utils_lib.get_memsize(self)
-        if utils_lib.is_arch(self, arch='aarch64') and utils_lib.get_memsize(self) < 16:
+        if utils_lib.is_arch(self, arch='aarch64') and utils_lib.get_memsize(self) < 100:
             #Hugepagesize is big in aarch64, so not run all hugetlb case in low memory arm system
             self._ltp_run(case_name="hugemmap01", file_name="hugetlb")
         elif utils_lib.get_memsize(self) < 4:
@@ -105,7 +106,7 @@ at least which ltp not handle')
     def test_ltp_ipsec_icmp(self):
         '''
         polarion_id: RHEL7-98754
-        BZ#: 1473593
+        bz: 1473593
         '''
         self._ltp_run(case_name="icmp4-uni-vti11",
                       file_name='net_stress.ipsec_icmp')
